=== modified file 'launchpadlib/wadl-to-refhtml.xsl'
--- launchpadlib/wadl-to-refhtml.xsl	2009-01-14 20:22:14 +0000
+++ launchpadlib/wadl-to-refhtml.xsl	2009-01-16 16:54:05 +0000
@@ -368,9 +368,7 @@
                 <var>&lt;id&gt;</var>
             </xsl:when>
             <xsl:when test="@id = 'commercial_subscription'">
-                <xsl:text>/</xsl:text>
                 <xsl:text>/+commercialsubscription/</xsl:text>
-                <xsl:text>/</xsl:text>
                 <var>&lt;commercial_subscription.id&gt;</var>
             </xsl:when>
             <xsl:otherwise>

=== modified file 'samples/_pythonpath.py'
--- samples/_pythonpath.py	2009-01-15 15:48:44 +0000
+++ samples/_pythonpath.py	2009-01-16 16:54:05 +0000
@@ -1,6 +1,7 @@
 __metaclass__ = type
 
-import sys, os, os.path
+import sys,
+import os
 
 # See if we can find launchpadlib and waddlib
 try:
@@ -9,6 +10,7 @@
 except ImportError:
     # Modify sys.path to add trunk/lib.
     HOME = os.environ['HOME']
-    trunk_path = os.environ.get('LP_TRUNK_PATH',
-                                os.path.join(HOME, 'canonical/lp-branches/trunk'))
+    trunk_path = os.environ.get(
+        'LP_TRUNK_PATH',
+        os.path.join(HOME, 'canonical/lp-branches/trunk'))
     sys.path.insert(0, os.path.join(trunk_path, 'lib'))

=== added file 'samples/commercial-member-api.py'
--- samples/commercial-member-api.py	1970-01-01 00:00:00 +0000
+++ samples/commercial-member-api.py	2009-01-16 16:54:05 +0000
@@ -0,0 +1,164 @@
+#!/usr/bin/python
+# -*-doctest-*-
+
+"""
+    >>> import _pythonpath, lpapi
+    >>> lp = lpapi.lp_factory('dev')
+    >>> bzr = lp.projects['bzr']
+    >>> bzr.reviewer_whiteboard = "Check on licensing"
+    >>> print bzr.reviewer_whiteboard
+    Check on licensing
+    >>> bzr.lp_save()
+    >>> print bzr.reviewer_whiteboard
+    Check on licensing
+
+    >>> from operator import attrgetter
+    >>> def print_projs(projs):
+    ...     for p in sorted(projs, key=attrgetter('name')):
+    ...         print p.name
+
+    >>> inactive = lp.projects.licensing_search(active=False)
+    >>> print_projs(inactive)
+    python-gnome2-dev
+    unassigned
+
+    >>> active = lp.projects.licensing_search(active=True)
+    >>> print_projs(active)
+    a52dec
+    alsa-utils
+    applets
+    aptoncd
+    arch-mirrors
+    bazaar
+    bzr
+    derby
+    evolution
+    firefox
+    gnome-terminal
+    gnomebaker
+    iso-codes
+    jokosher
+    landscape
+    launchpad
+    mega-money-maker
+    netapplet
+    redfish
+    rosetta
+    thunderbird
+    tomcat
+    upstart
+
+
+    >>> projs = lp.projects.licensing_search(license_reviewed=False)
+    >>> print_projs(projs)
+    a52dec
+    applets
+    aptoncd
+    arch-mirrors
+    bazaar
+    bzr
+    derby
+    evolution
+    firefox
+    gnome-terminal
+    gnomebaker
+    iso-codes
+    jokosher
+    landscape
+    launchpad
+    mega-money-maker
+    netapplet
+    redfish
+    thunderbird
+    tomcat
+    upstart
+
+    >>> projs = lp.projects.licensing_search(has_zero_licenses=True)
+    >>> print_projs(projs)
+    a52dec
+    alsa-utils
+    applets
+    aptoncd
+    arch-mirrors
+    bazaar
+    bzr
+    evolution
+    firefox
+    gnome-terminal
+    gnomebaker
+    iso-codes
+    jokosher
+    landscape
+    launchpad
+    netapplet
+    python-gnome2-dev
+    redfish
+    rosetta
+    thunderbird
+    unassigned
+    upstart
+
+    >>> projs = lp.projects.licensing_search(licenses=['Other/Proprietary'])
+    >>> print_projs(projs)
+    mega-money-maker
+
+    >>> bzr.licenses
+    []
+
+    >>> projs = lp.projects.licensing_search(has_zero_licenses=False)
+    >>> print_projs(projs)
+    derby
+    mega-money-maker
+    tomcat
+
+    >>> projs[0].licenses
+    [u'Apache License']
+    >>> projs[1].licenses
+    [u'Other/Proprietary']
+    >>> projs[2].licenses
+    [u'Academic Free License', u'GNU Affero GPL v3']
+
+    >>> projs = lp.projects.licensing_search(licenses=['GNU Affero GPL v3'])
+    >>> print_projs(projs)
+    tomcat
+
+    >>> projs = lp.projects.licensing_search(
+    ...     subscription_expires_after="2005-01-01")
+    >>> print_projs(projs)
+    >>> projs = lp.projects.licensing_search(has_zero_licenses=True,
+    ...                                      search_text="Bazaar")
+    >>> print_projs(projs)
+    bazaar
+    bzr
+    launchpad
+
+    >>> l = projs[2]
+    >>> print l.name
+    launchpad
+    >>> print l.description
+    Launchpad's design is inspired by the Description of a Project (DOAP) framework by Edd Dumbill, with extensions for actual releases of products.
+    >>> print l.summary
+    Launchpad is a catalogue of libre software projects and products. Projects registered in the Launchpad are linked to their translations in Rosetta, their bugs in Malone, their RCS imports in Bazaar, and their packages in Soyuz.
+
+"""
+
+if __name__ == '__main__':
+    # Remove existing credentials.
+    import os
+    try:
+        os.unlink(os.path.join(os.environ['HOME'], 'dev.auth'))
+    except OSError:
+        pass
+
+    # Create correct credentials.
+    print "Login as 'commercial-member@canonical.com' in your browser."
+    print "Press <Enter> when done."
+    raw_input()
+
+    # Import _pythonpath and the lpapi module.  _pythonpath must
+    # precede the import of lpapi as it redefines sys.path.
+    import _pythonpath, lpapi
+    lp = lpapi.lp_factory('dev')
+
+    import doctest
+    doctest.testmod()

=== modified file 'samples/lpapi.py'
--- samples/lpapi.py	2009-01-15 15:48:44 +0000
+++ samples/lpapi.py	2009-01-16 16:54:05 +0000
@@ -17,24 +17,26 @@
 
 
 class InvalidCredentials(Exception):
-    pass
-
-
-class Retry(Exception):
+    """Exception for invalid credentials."""
     pass
 
 
 class LPSystem:
+    """Launchpad system class.
+
+    Handles retrieving credentials and connecting to the appropriate API
+    endpoint.
+    """
     endpoint = None
     auth_file = None
     def __init__(self, app_name='just testing', use_cache=True):
         home = os.environ['HOME']
         if use_cache:
-            cachedir = os.path.join(home, '.launchpadlib', 'cache')
-            if not os.path.exists(cachedir):
-                cachedir = None
+            cache_dir = os.path.join(home, '.launchpadlib', 'cache')
+            if not os.path.exists(cache_dir):
+                cache_dir = None
         else:
-            cachedir = None
+            cache_dir = None
         try:
             # Load credentials from AUTH_FILE if it exists.
             self.auth_file = os.path.join(home, self.auth_file_name)
@@ -43,17 +45,18 @@
             print >> sys.stderr, "Loading credentials..."
             try:
                 self.launchpad = Launchpad(self.credentials, self.endpoint,
-                                           cache=cachedir)
+                                           cache=cache_dir)
             except launchpadlib.errors.HTTPError:
                 raise InvalidCredentials, (
                     "Please remove %s and rerun %s to authenticate." % (
                     self.auth_file, sys.argv[0]))
         except IOError:
-            # Prompt for authentication process, then save credentials to AUTH_FILE.
+            # Prompt for authentication process, then save credentials to
+            # AUTH_FILE.
             try:
                 self.launchpad = Launchpad.get_token_and_login(app_name,
                                                                self.endpoint,
-                                                               cache=cachedir)
+                                                               cache=cache_dir)
                 self.launchpad.credentials.save(open(self.auth_file, "w"))
                 print >> sys.stderr, "Credentials saved"
             except launchpadlib.errors.HTTPError, err:
@@ -66,43 +69,46 @@
 
 
 class Edge(LPSystem):
+    """Connection to edge."""
     endpoint = EDGE_SERVICE_ROOT
     auth_file_name = 'edge.auth'
 
 
 class Staging(LPSystem):
+    """Connection to staging."""
     endpoint = STAGING_SERVICE_ROOT
     auth_file_name = 'staging.auth'
 
 
 class Production(LPSystem):
+    """Connection to production."""
     endpoint = 'https://api.launchpad.net/beta/'
     auth_file_name = 'production.auth'
 
 
 class Dev(LPSystem):
+    """Connection to local development version of Launchpad."""
     endpoint = 'https://api.launchpad.dev/beta/'
     auth_file_name = 'dev.auth'
     def __init__(self, app_name='just testing'):
         LPSystem.__init__(self, app_name=app_name, use_cache=False)
 
 
-systems=dict(dev=Dev,
-             staging=Staging,
-             edge=Edge,
-             beta=Edge,
-             production=Production,
-             prod=Production,
-             )
-
-
-def lp_factory(sysname, app_name='just_testing'):
-    """Get a launchpad API instance for `sysname`."""
+systems = dict(dev=Dev,
+               staging=Staging,
+               edge=Edge,
+               production=Production,
+               prod=Production,
+               )
+
+
+def lp_factory(system_name, app_name='just_testing'):
+    """Get a launchpad API instance for ``system_name``."""
     try:
-        sysname = sysname.lower()
-        lpinstance = systems[sysname]
+        system_name = system_name.lower()
+        lpinstance = systems[system_name]
         return lpinstance(app_name).launchpad
     except KeyError:
-        print >> sys.stderr, "System '%s' not supported." % sysname
+        print >> sys.stderr, "System '%s' not supported." % system_name
         print >> sys.stderr, "Use one of: ", systems.keys()
         return None

=== modified file 'samples/nopriv-api.py'
--- samples/nopriv-api.py	2009-01-15 15:47:01 +0000
+++ samples/nopriv-api.py	2009-01-16 16:54:05 +0000
@@ -17,11 +17,6 @@
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> from operator import attrgetter
-    >>> def print_projs(projs):
-    ...     for p in sorted(projs, key=attrgetter('name')):
-    ...         print p.name
-
     >>> inactive = lp.projects.licensing_search(active=False)
     Traceback (most recent call last):
     ...
@@ -60,12 +55,14 @@
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> projs = lp.projects.licensing_search(subscription_expires_after="2005-01-01")
+    >>> projs = lp.projects.licensing_search(
+    ...     subscription_expires_after="2005-01-01")
     Traceback (most recent call last):
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> projs = lp.projects.licensing_search(has_zero_licenses=True, search_text="Bazaar")
+    >>> projs = lp.projects.licensing_search(has_zero_licenses=True,
+    ...                                      search_text="Bazaar")
     Traceback (most recent call last):
     ...
     HTTPError: HTTP Error 401: Unauthorized
@@ -85,6 +82,8 @@
     print "Press <Enter> when done."
     raw_input()
 
+    # Import _pythonpath and the lpapi module.  _pythonpath must
+    # precede the import of lpapi as it redefines sys.path.
     import _pythonpath, lpapi
     lp = lpapi.lp_factory('dev')
     import doctest

=== modified file 'samples/sample-person-api.py'
--- samples/sample-person-api.py	2009-01-15 16:45:22 +0000
+++ samples/sample-person-api.py	2009-01-16 16:54:05 +0000
@@ -17,11 +17,6 @@
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> from operator import attrgetter
-    >>> def print_projs(projs):
-    ...     for p in sorted(projs, key=attrgetter('name')):
-    ...         print p.name
-
     >>> inactive = lp.projects.licensing_search(active=False)
     Traceback (most recent call last):
     ...
@@ -60,12 +55,14 @@
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> projs = lp.projects.licensing_search(subscription_expires_after="2005-01-01")
+    >>> projs = lp.projects.licensing_search(
+    ...     subscription_expires_after="2005-01-01")
     Traceback (most recent call last):
     ...
     HTTPError: HTTP Error 401: Unauthorized
 
-    >>> projs = lp.projects.licensing_search(has_zero_licenses=True, search_text="Bazaar")
+    >>> projs = lp.projects.licensing_search(has_zero_licenses=True,
+    ...                                      search_text="Bazaar")
     Traceback (most recent call last):
     ...
     HTTPError: HTTP Error 401: Unauthorized
@@ -85,6 +82,8 @@
     print "Press <Enter> when done."
     raw_input()
 
+    # Import _pythonpath and the lpapi module.  _pythonpath must
+    # precede the import of lpapi as it redefines sys.path.
     import _pythonpath, lpapi
     lp = lpapi.lp_factory('dev')
     import doctest

